Learn R Programming

tcv (version 0.1.0)

chooseFacNumber_ratio: Estimating the Number of Factor by Eigenvalue Ratio of Natural Parameter Matrix in Generalized Factor Model.

Description

Estimating the Number of Factor by Eigenvalue Ratio of Natural Parameter Matrix in Generalized Factor Model.

Usage

chooseFacNumber_ratio(
  XList,
  types,
  q_set = 1:5,
  select_method = c("SVR", "IC"),
  offset = FALSE,
  dc_eps = 1e-04,
  maxIter = 30,
  verbose = FALSE,
  parallelList = NULL
)

Value

The number of factors estimated by ratio methods.

Arguments

XList

A list that containing an n by p matrix, where n is the number of samples, p is the number of features.

types

The type of data. In Poisson factor models, the type is "poisson".

q_set

The maximum number of factors for conducting ratio methods. Default as 5.

select_method

The methods to conduct GFM. Default as AM.

offset

Default as FALSE.

dc_eps

The tolerance for convergence. Default as 1e-4.

maxIter

The maximum iteration times. Defualt as 30.

verbose

Default as FALSE

parallelList

Whether to use parallel. Default as NULL.