Estimating the Number of Factor by Eigenvalue Ratio of Natural Parameter Matrix in Generalized Factor Model.
chooseFacNumber_ratio(
XList,
types,
q_set = 1:5,
select_method = c("SVR", "IC"),
offset = FALSE,
dc_eps = 1e-04,
maxIter = 30,
verbose = FALSE,
parallelList = NULL
)The number of factors estimated by ratio methods.
A list that containing an n by p matrix, where n is the number of samples, p is the number of features.
The type of data. In Poisson factor models, the type is "poisson".
The maximum number of factors for conducting ratio methods. Default as 5.
The methods to conduct GFM. Default as AM.
Default as FALSE.
The tolerance for convergence. Default as 1e-4.
The maximum iteration times. Defualt as 30.
Default as FALSE
Whether to use parallel. Default as NULL.